# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-MooseX-NonMoose
Version:	0.26
Release:	26.%{__distinit}%{__distvers}
Summary:	Easy subclassing of non-Moose classes
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/MooseX-NonMoose
Source0:	https://cpan.metacpan.org/modules/by-module/MooseX/MooseX-NonMoose-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.30
BuildRequires:	perl(strict)
# Module Runtime
BuildRequires:	perl(List::MoreUtils)
BuildRequires:	perl(Module::Runtime)
BuildRequires:	perl(Moose::Exporter)
BuildRequires:	perl(Moose::Role) >= 2.0000
BuildRequires:	perl(Moose::Util)
BuildRequires:	perl(Try::Tiny)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(base)
BuildRequires:	perl(blib)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(Moose) >= 2.1203
BuildRequires:	perl(Test::Fatal)
BuildRequires:	perl(Test::Moose)
BuildRequires:	perl(Test::More) >= 0.88
# Optional Tests
BuildRequires:	perl(IO::File)
BuildRequires:	perl(MooseX::GlobRef)
BuildRequires:	perl(MooseX::InsideOut) >= 0.100
# Release Tests
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Test::EOL)
BuildRequires:	perl(Test::NoTabs)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
MooseX::NonMoose allows for easily subclassing non-Moose classes with Moose,
taking care of the annoying details connected with doing this, such as setting
up proper inheritance from Moose::Object and installing (and inlining, at
make_immutable time) a constructor that makes sure things like BUILD methods
are called. It tries to be as non-intrusive as possible - when this module is
used, inheriting from non-Moose classes and inheriting from Moose classes
should work identically, aside from the few caveats mentioned below. One of the
goals of this module is that including it in a Moose::Exporter-based package
used across an entire application should be possible, without interfering with
classes that only inherit from Moose modules, or even classes that don't
inherit from anything at all.

%prep
%setup -q -n MooseX-NonMoose-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test RELEASE_TESTING=1

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/MooseX/
%{_mandir}/man3/MooseX::NonMoose.3*
%{_mandir}/man3/MooseX::NonMoose::InsideOut.3*
%{_mandir}/man3/MooseX::NonMoose::Meta::Role::Class.3*
%{_mandir}/man3/MooseX::NonMoose::Meta::Role::Constructor.3*

%changelog
* Mon May  1 2023 Paul Howarth <paul@city-fan.org> - 0.26-26
- Use SPDX-format license tag
- Use %%license unconditionally

* Tue Mar 10 2020 Paul Howarth <paul@city-fan.org> - 0.26-17
- BR: perl(blib) for t/00-compile.t

* Thu Apr 26 2018 Paul Howarth <paul@city-fan.org> - 0.26-10
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Fri Jun 16 2017 Paul Howarth <paul@city-fan.org> - 0.26-7
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88
  - BR: perl(MooseX::InsideOut) unconditionally

* Wed Sep  7 2016 Paul Howarth <paul@city-fan.org> - 0.26-5
- Fix FTBFS when perl is not in the minimal buildroot
- Classify buildreqs by usage
- Simplify find command using -delete

* Wed Sep 17 2014 Paul Howarth <paul@city-fan.org> - 0.26-2
- Drop support for building with ExtUtils::MakeMaker < 6.30
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Wed Feb 26 2014 Paul Howarth <paul@city-fan.org> - 0.26-1
- Update to 0.26
  - Fix dependency specification for Try::Tiny
    (https://github.com/doy/moosex-nonmoose/pull/9)

* Fri Feb  7 2014 Paul Howarth <paul@city-fan.org> - 0.25-1
- Update to 0.25
  - Fix for Module::Runtime 0.014
- Update buildreqs and patches as needed

* Mon Sep  9 2013 Paul Howarth <paul@city-fan.org> - 0.24-1
- Update to 0.24
  - Added missing lib include

* Thu Sep  5 2013 Paul Howarth <paul@city-fan.org> - 0.23-1
- Update to 0.23
  - Stop using old and deprecated (or soon to be deprecated) functions from
    Class::MOP
- Update buildreqs and patches as needed

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 0.22-4
- BR: perl(base), perl(File::Temp), perl(IO::File), perl(IO::Handle),
  perl(Moose::Exporter) and perl(Moose::Role)
- Specify version requirement perl(MooseX::InsideOut)
- Don't need to remove empty directories from the buildroot

* Tue Oct 18 2011 Paul Howarth <paul@city-fan.org> - 0.22-3
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Jul  5 2011 Paul Howarth <paul@city-fan.org> - 0.22-2
- Rebuild for perl 5.14.1 in Rawhide

* Mon May  9 2011 Paul Howarth <paul@city-fan.org> - 0.22-1
- Import from Fedora
- Update to 0.22:
  - Fix issues where the metaclass gets reinitialized after the call to
    'extends' but before 'make_immutable'; this could happen if a role used an
    extension which provided an application_to_class metarole, since the role
    application would then apply a metarole to the class, and metarole
    application currently causes metaclass reinitialization in Moose

* Wed May 04 2011 Iain Arnell <iarnell@gmail.com> - 0.21-1
- Update to latest upstream version

* Wed Mar 23 2011 Iain Arnell <iarnell@gmail.com> - 0.20-1
- Update to latest upstream version

* Fri Mar 04 2011 Iain Arnell <iarnell@gmail.com> - 0.19-1
- Update to latest upstream version

* Wed Feb 16 2011 Iain Arnell <iarnell@gmail.com> - 0.18-1
- Update to latest upstream version
- BR perl(MooseX::GlobRef) for additional test coverage

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.17-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Nov 19 2010 Iain Arnell <iarnell@gmail.com> - 0.17-1
- Update to latest upstream version

* Wed Nov 03 2010 Iain Arnell <iarnell@gmail.com> - 0.16-2
- Requires Moose ≥ 1.15

* Wed Oct 27 2010 Iain Arnell <iarnell@gmail.com> - 0.16-1
- Update to latest upstream version

* Tue Oct 05 2010 Iain Arnell <iarnell@gmail.com> - 0.15-1
- Specfile autogenerated by cpanspec 1.78
